#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 distributive
version:              0.6.2.1
visibility:           public
id:                   distributive-0.6.2.1-Cpe8IWChck2JiewHveyuC7
key:                  distributive-0.6.2.1-Cpe8IWChck2JiewHveyuC7
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/distributive/
synopsis:             Distributive functors -- Dual to Traversable
description:          Distributive functors -- Dual to @Traversable@
category:             Data Structures
abi:                  038ccdcf5da539ec65896fc0957c06d9
exposed:              True
exposed-modules:      Data.Distributive Data.Distributive.Generic
import-dirs:          /usr/lib/ghc-9.6.6/site-local/distributive-0.6.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/distributive-0.6.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/distributive-0.6.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-distributive
hs-libraries:         HSdistributive-0.6.2.1-Cpe8IWChck2JiewHveyuC7
depends:
    base-4.18.2.1 base-orphans-0.9.3-6uXzwgwQfg3LrL5z3rsWmt
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-distributive/html/distributive.haddock

haddock-html:         /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

